<?php
if (!defined( 'ABSPATH')) exit;

if ( ! function_exists('qeapps_pwa_get_filename')) {
    function qeapps_pwa_get_filename($arg) {
        if($arg == "service_worker")return 'qeapps-pwa-service-worker.json';
        if($arg == "manifest")return 'qeapps-pwa-manifest.json';
    }
}
if ( ! function_exists('get_qeapps_pwa_icons')) {
    function get_qeapps_pwa_icons() {
        
        $icons_array[] = get_qeapps_pwa_application_icon();
        $icons_array[] = get_qeapps_pwa_splash_icon();
        return $icons_array;
    }
}
if ( ! function_exists('get_qeapps_pwa_application_icon')) {
    function get_qeapps_pwa_application_icon() {
        
        // Get settings
        $settings = qeapps_pwa_get_settings();
        // Application icon
        $icons_array = array();

        if (is_array($settings) && count($settings) > 0 && $settings['qeapps_pwa_icon'] != '' ) {
            
            $icons_array = array(
                'src'   => esc_url($settings['qeapps_pwa_icon']),
                'sizes' => esc_attr('192x192'),
                'type'  => esc_attr('image/png'),
            );

        }else{

            $icons_array = array(
                'src'   => esc_url(QEAPPS_APPLICATION_ICON),
                'sizes' => esc_attr('192x192'),
                'type'  => esc_attr('image/png'),
            );
        }
        
        return $icons_array;
    }
}
if ( ! function_exists('get_qeapps_pwa_splash_icon')) {
    function get_qeapps_pwa_splash_icon() {
        
        // Get settings
        $settings = qeapps_pwa_get_settings();
        // Application icon
        $icons_array = array();
        if (is_array($settings) && count($settings) > 0 && $settings['qeapps_pwa_splash_icon'] != '' ) {
            
            $icons_array = array(
                'src'   => esc_url($settings['qeapps_pwa_splash_icon']),
                'sizes' => '512x512',
                'type'  => 'image/png',
            );
        }
        else{
            
            $icons_array = array(
                'src'   => esc_url(QEAPPS_SPLASH_ICON),
                'sizes' => '512x512',
                'type'  => 'image/png',
            );
        }
        
        return $icons_array;
    }
}

if ( ! function_exists('qeapps_pwa_apple_touch_icon')) {
    function qeapps_pwa_apple_touch_icon( $tags='' ) {

        $icons = get_qeapps_pwa_icons();
        // Get settings
        $settings = qeapps_pwa_get_settings();
        
        $tags .= '<meta name="mobile-web-app-capable" content="yes">' . PHP_EOL;
        $tags .= '<meta name="apple-touch-fullscreen" content="yes">' . PHP_EOL;
        $tags .= '<meta name="apple-mobile-web-app-title" content="'.esc_attr($settings['qeapps_pwa_name']).'">' . PHP_EOL;
        $tags .= '<meta name="application-name" content="'.esc_attr($settings['qeapps_pwa_name']).'">' . PHP_EOL;
        $tags .= '<meta name="apple-mobile-web-app-capable" content="yes">' . PHP_EOL;
        $tags .= '<meta name="apple-mobile-web-app-status-bar-style" content="default">' . PHP_EOL;

        if(is_array($icons) && count($icons) > 0):
            foreach( $icons as $icon ) :
                if( isset($icon['sizes']) && isset($icon['src']) ):
                    $tags .= '<link rel="apple-touch-icon" sizes="' . esc_attr($icon['sizes'],'qeapps-pwa') . '" href="' . esc_url($icon['src'],'qeapps-pwa') . '">' . PHP_EOL;
                endif;
            endforeach;//foreach
        endif;
        
        //Ios splash screen
        $iosSetting = get_option( 'qeapps_pwa_apple_icons_uploaded' );
        if( $iosSetting && isset($iosSetting['ios_splash_icon']) && !empty($iosSetting['ios_splash_icon']) ) :
            $iconsInfo = qeappspwa_apple_splashscreen_files();

            foreach ( $iosSetting['ios_splash_icon'] as $key => $value ) :
                if( !empty($value) && !empty($key) && isset($iconsInfo[$key]) ) :
                    $screenData = $iconsInfo[$key];
                    $tags .= '<link rel="apple-touch-startup-image" media="screen and (device-width: '.esc_attr($screenData['image-width']).') and (device-height: '.esc_attr($screenData['image-height']).') and (-webkit-device-pixel-ratio: '.esc_attr($screenData['ratio']).') and (orientation: '.esc_attr($screenData['orientation']).')" href="'.esc_url($value).'"/>'."\n";
                endif;//if 
            endforeach;//foreach
        endif;//if 
        return $tags;
    }
}

if ( ! function_exists('qeapps_pwa_default_settings')) {
    function qeapps_pwa_default_settings() {

        $front_page_id = get_option('page_on_front');
        return array(
            'qeapps_pwa_name'           => get_bloginfo( 'name' ),
            'qeapps_pwa_short_name'     => substr( get_bloginfo( 'name' ), 0, 15 ),
            'qeapps_pwa_description'    => esc_attr('Welcome to our store'),
            'qeapps_pwa_icon'           => esc_url(QEAPPS_APPLICATION_ICON),
            'qeapps_pwa_splash_icon'    => esc_url(QEAPPS_SPLASH_ICON),
            'qeapps_pwa_background_color'  => esc_attr('#106d57'),
            'qeapps_pwa_theme_color'       => esc_attr('#15a826'),
            'qeapps_pwa_start_url'         => $front_page_id,
            //'qeapps_pwa_offline_page'      => $front_page_id,
            'qeapps_pwa_orientation'       => esc_attr('portrait'),
            'qeapps_pwa_display'           => esc_attr('fullscreen'),
            'qeapps_pwa_disable_add_to_home'=> 0,                      
        );
    }
}
if ( ! function_exists('qeapps_pwa_get_settings')) {
    function qeapps_pwa_get_settings() {

        $defaults = qeapps_pwa_default_settings();
        $settings = get_option( 'qeapps_pwa_manifest_settings', $defaults );
        return $settings;
    }
}
if ( ! function_exists('qeapps_pwa_get_start_url')) {
    function qeapps_pwa_get_start_url( $rel = false ) {

        $settings = qeapps_pwa_get_settings();
        $start_url = (isset($settings['qeapps_pwa_start_url']) && $settings['qeapps_pwa_start_url'] > 0) ? esc_url(get_permalink( $settings['qeapps_pwa_start_url'] )) : esc_url(site_url());

        if ( $rel === true ) {
            $start_url = ( parse_url( $start_url, PHP_URL_PATH ) == '' ) ? '.' : parse_url( $start_url, PHP_URL_PATH );        
            return apply_filters( 'qeapps_pwa_get_start_url', $start_url );
        }
        
        return $start_url;
    }
}
/*if ( ! function_exists('qeapps_pwa_get_offline_page')) {
    function qeapps_pwa_get_offline_page() {
        
        $settings = qeapps_pwa_get_settings();
        return ( isset($settings['qeapps_pwa_offline_page']) && $settings['qeapps_pwa_offline_page']  > 0 ) ? get_permalink( $settings['qeapps_pwa_offline_page'] ) :  site_url();
    }
}*/
if ( ! function_exists('qeapps_pwa_file_exists')) {
    function qeapps_pwa_file_exists( $file ) {
        
        $response       = wp_remote_head( $file, array( 'sslverify' => false ) );
        $response_code  = wp_remote_retrieve_response_code( $response );
        if ( $response_code === 200 ) {
            return true;
        }
        return false;
    }
}
if ( ! function_exists('qeappspwa_hexToRgb')) {
    function qeappspwa_hexToRgb($hex, $alpha = false) {

       $hex      = str_replace('#', '', $hex);
       $length   = strlen($hex);
       $rgb['r'] = hexdec($length == 6 ? substr($hex, 0, 2) : ($length == 3 ? str_repeat(substr($hex, 0, 1), 2) : 0));
       $rgb['g'] = hexdec($length == 6 ? substr($hex, 2, 2) : ($length == 3 ? str_repeat(substr($hex, 1, 1), 2) : 0));
       $rgb['b'] = hexdec($length == 6 ? substr($hex, 4, 2) : ($length == 3 ? str_repeat(substr($hex, 2, 1), 2) : 0));
       if ( $alpha ) {
          $rgb['a'] = $alpha;
       }
       return $rgb;
    }
}

if ( ! function_exists('qeappspwa_apple_splashscreen_files')) {
    function qeappspwa_apple_splashscreen_files(){
        $ArrData = array(
                '1136x640'=> array("image-width"=> '320px', "image-height"=> "568px","ratio"=> 2,"orientation"=> "landscape","file"=> "icon_1136x640.png",'name'=> 'iPhone 5/iPhone SE'),
                '640x1136'=> array("image-width"=> '320px', "image-height"=> "568px","ratio"=> 2,"orientation"=> "portrait", "file"=> "icon_640x1136.png",'name'=> 'iPhone 5/iPhone SE'),
                '2688x1242'=>array("image-width"=> '414px', "image-height"=> "896px","ratio"=> 3,"orientation"=> "landscape", "file"=> "icon_2688x1242.png", 'name'=>'iPhone XS Max'),
                '1792x828'=> array("image-width"=> '414px', "image-height"=> "896px","ratio"=> 2, "orientation"=> "landscape", "file"=> "icon_1792x828.png", 'name'=>'iPhone XR'),
                '1125x2436'=>array("image-width"=> '375px', "image-height"=> "812px","ratio"=> 3,"orientation"=> 'portrait', "file"=>"icon_1125x2436.png", 'name'=> 'iPhone X/Xs'),
                '828x1792'=> array("image-width"=> "414px", "image-height"=> "896px","ratio"=> 2,"orientation"=> "portrait","file"=>"icon_828x1792.png",'name' => 'iPhone Xr'),
                '2436x1125'=> array("image-width"=> "375px","image-height"=> "812px","ratio"=> 3,"orientation"=> "landscape", "file"=>"icon_2436x1125.png", 'name'=> 'iPhone X/Xs'),
                '1242x2208'=> array("image-width"=> "414px","image-height"=> "736px","ratio"=> 3,"orientation"=> "portrait", "file"=>"icon_1242x2208.png", 'name'=> 'iPhone 6/7/8 Plus'),
                '2208x1242'=>array("image-width"=> "414px","image-height"=> "736px","ratio"=> 3,"orientation"=> "landscape", "file"=>"icon_2208x1242.png", 'name'=> 'iPhone 6/7/8 Plus'),
                '1334x750'=>array("image-width"=> "375px","image-height"=> "667px","ratio"=> 2,"orientation"=> "landscape", "file"=>"icon_1334x750.png", 'name'=> 'iPhone 6/7/8'),
                '750x1334'=>array("image-width"=> "375px","image-height"=> "667px","ratio"=> 2,"orientation"=> "portrait","file"=>"icon_750x1334.png", 'name'=> 'iPhone 6/7/8'),
                '2732x2048'=>array("image-width"=> "1024px","image-height"=>"1366px","ratio"=> 2,"orientation"=> "landscape","file"=>"icon_2732x2048.png", 'name'=> 'iPad Pro 12.9"'),
                '2048x2732'=>array("image-width"=> "1024px","image-height"=> "1366px","ratio"=> 2,"orientation"=> "portrait","file"=>"icon_2048x2732.png", 'name'=> 'iPad Pro 12.9"'),
                '2388x1668'=>array("image-width"=> "834px","image-height"=> "1194px","ratio"=> 2,"orientation"=> "landscape", "file"=>"icon_2388x1668.png",'name'=> 'iPad Pro 11"'),
                '1668x2388'=>array("image-width"=> "834px","image-height"=> "1194px","ratio"=> 2,"orientation"=> "portrait","file"=>"icon_1668x2388.png",'name'=> 'iPad Pro 11"'),
                '2224x1668'=>array("image-width"=> "834px", "image-height"=> "1112px","ratio"=> 2,"orientation"=>"landscape","file"=>"icon_2224x1668.png", 'name'=> 'iPad Pro 10.5"'),
                '1242x2688'=>array("image-width"=> "414px","image-height"=> "896px","ratio"=> 3, "orientation"=> "portrait","file"=>"icon_1242x2688.png", 'name' => 'iPhone Xs Max'),
                '1668x2224'=>array("image-width"=> "834px","image-height"=> "1112px","ratio"=> 2, "orientation"=> "portrait","file"=>"icon_1668x2224.png", 'name'=> 'iPad Pro 10.5"'),
                '1536x2048'=>array("image-width"=> "768px","image-height"=> "1024px","ratio"=> 2, "orientation"=> "portrait","file"=>"icon_1536x2048.png", 'name'=> 'iPad Mini/iPad Air'),
                '2048x1536'=>array("image-width"=> "768px","image-height"=> "1024px","ratio"=> 2,"orientation"=> "landscape","file"=>"icon_2048x1536.png", 'name'=> 'iPad Mini/iPad Air'),
                );
        return $ArrData;
    }
}
if ( ! function_exists('qeappspwa_splashscreen_uploader')) {
    function qeappspwa_splashscreen_uploader($color_code,$iconImage){

        $file_name = array();
        $rgb = qeappspwa_hexToRgb($color_code);
        $r = $rgb['r'];
        $g = $rgb['g'];
        $b = $rgb['b'];
        $icon_image_info = getimagesize($iconImage);
        $width = $icon_image_info[0];
        $height = $icon_image_info[1];

        $upload = wp_upload_dir();
        $baseurl = $upload['baseurl']."/qeappspwa-splashIcons";
        $path =  $upload['basedir']."/qeappspwa-splashIcons";
        wp_mkdir_p($path);
        file_put_contents($path.'/index.html','');
        WP_Filesystem();

        $IMG = imagecreate(1000,1000);
        $background = imagecolorallocate($IMG, $r, $g, $b);
        imagesetthickness ( $IMG, 5 );
        imagepng($IMG,$path."/splash.png");

        $leftsizepx = 100;
        $topsizepx = 100;
        $splashImage = $path."/splash.png";
        $devices_resolution =  qeappspwa_apple_splashscreen_files();    

        foreach($devices_resolution as $key => $device)
        {
            $Arrdiamention = explode('x',$key);
            $bw = $Arrdiamention[0];
            $bh = $Arrdiamention[1];
            
            $left = ($bw / 2)- ($width / 2);
            $top = ($bh / 2) - ($height / 2);

            $splash_image = imagecreatefrompng($splashImage);
            $icon_image = imagecreatefrompng($iconImage);
            $final_img = imagecreatetruecolor($bw, $bh);
            
            imagecopy($final_img, $splash_image, 0, 0, 0, 0, $bw, $bh);
            imagecopymerge($final_img, $icon_image, $left, $top, 0, 0, $width, $height,100);
            imagepng($final_img,$path."/".$device['file']);
            
        }
        $iosSetting = (array)get_option( 'qeapps_pwa_apple_icons_uploaded' ) ;
        foreach ($devices_resolution as $key => $value) {
             $iosSetting['ios_splash_icon'][$key] = $baseurl."/".$value['file'];
        }
        update_option( 'qeapps_pwa_apple_icons_uploaded', $iosSetting ) ;    
    }
}
if ( ! function_exists('qeappspwa_display_dynamic_error_notice')) {
    function qeappspwa_display_dynamic_error_notice($notice)
    {
        printf(__('<div class="notice notice-error"> <p>%s</p></div>', 'qe-seo-handyman') , sanitize_text_field($notice));
    }
}

if ( ! function_exists('qeappspwa_display_dynamic_success_notice')) {
    function qeappspwa_display_dynamic_success_notice($notice)
    {
        printf(__('<div class="updated"> <p>%s</p></div>', 'qeapps-pwa') , sanitize_text_field($notice));
    }
}

if ( ! function_exists('qeappspwa_support_form')) {
    function qeappspwa_support_form(){
        ?>
            <div class="qeappspwa-support-wrapper">
                <form name="pwa_help_frm" id="pwa_help_frm" action="<?php echo esc_attr(admin_url('admin-post.php')); ?>" method="post" enctype='multipart/form-data' >
                    <input type="hidden" name="action" value="<?php esc_html_e('qeappspwa_support','qeapps-pwa'); ?>" />
                    <input type="hidden" name="nonce_qeappspwa_support" value="<?php echo wp_create_nonce('qeappspwa_support'); ?>">
                    <input type="hidden" name="qeappspwa_domain" value="<?php echo esc_url(site_url('/')); ?>" />
                    <fieldset>
                        <label><?php _e( 'Email', 'qeapps-pwa' ); ?></label>
                        <input name="qeappspwa_email" value="<?php $user = wp_get_current_user(); echo esc_attr( $user->user_email ); ?>" placeholder="<?php _e( 'Enter your email', 'qeapps-pwa' ); ?>" style="width: 60%; margin-left: 0px;" type="email" required>
                    </fieldset>
                    <fieldset>
                        <label><?php _e( 'Message', 'qeapps-pwa' ); ?></label>
                        <textarea class="qeappspwa-message" name="qeappspwa_message" rows="5" width="100%" placeholder="<?php _e( 'Message', 'qeapps-pwa' ); ?>" required></textarea>
                    </fieldset>
                    <fieldset>
                        <?php submit_button( __('Send Message', 'qeapps-pwa'),"qeapps-submit-class" ); ?>
                    </fieldset>
                </form>
            </div>
        <?php 
    }
}
if ( ! function_exists('qeappspwa_send_mail_process')) {
    function qeappspwa_send_mail_process($ArrData){

        $response = wp_remote_post( esc_attr('http://www.qeapps.com/pwa_help_inquiry.php') , array(
            'method'      => 'POST',
            'timeout'     => 45,
            'redirection' => 5,
            'httpversion' => '1.0',
            'blocking'    => true,
            'headers'     => array(),
            'body'        => array(
                'customer_email' => sanitize_text_field($ArrData['email']),
                'message' => sanitize_text_field($ArrData['message']),
                'bloginfo' => sanitize_text_field($ArrData['bloginfo']),
                'site_url' => sanitize_text_field($ArrData['site_url']),
            ),
            'cookies'     => array()
            )
        );
         
        if ( is_wp_error( $response ) ) {
            $error_message = $response->get_error_message();
            update_option('qeappspwa_email_error_message', "Something went wrong to send email,Please try after some time.", 'no');
            $url = wp_sanitize_redirect(admin_url('admin.php?page=easy-progressive-web-app#pwahelp-settings'));
            wp_redirect($url);
            exit; 
        } else {
            update_option('qeappspwa_email_success_message', "Thanks For Contact us.", 'no');
            $url = wp_sanitize_redirect(admin_url('admin.php?page=easy-progressive-web-app#pwahelp-settings'));
            wp_redirect($url);
            exit;
        }
        
    }

}


if ( ! function_exists('qeapps_pwa_cta_banner')) {
    function qeapps_pwa_cta_banner(){
        $settings = qeapps_pwa_get_settings();

        $html  = '<!-- CTA By Easy PWA -->' . PHP_EOL;
            $html  .= '<div class="easy_pwa_cta_banner_section" style="display:none"> 
                <div class="easy_pwa_cta_banner_innerbox"> 
                    <div class="cta_banner_left"><img class="cta_banner_icon" src="'.esc_url($settings['qeapps_pwa_icon']).'"></div>
                    <div class="cta_banner_center"><button class="cta_banner_button"> Add To Home Screen </button></div>
                    <div class="cta_banner_right"><span class="cta_banner_close">X</span></div> 
                </div>
            </div>

            <div class="easy_pwa_cta_banner_popup_section" style="display: none;">   
                <link href="https://maxcdn.bootstrapcdn.com/font-awesome/4.2.0/css/font-awesome.min.css" rel="stylesheet">
                <div class="in_popup_main_div">
                    <div class="popup_button_close">X</div>
                    <div class="popup_main_app_logo">
                        <img src="'.esc_url($settings['qeapps_pwa_icon']).'" id="logo_for_device">
                    </div>
                    <div class="installheader"> Get Ready </div>
                    <div class="installmessage_android">
                        <p>Our app does not take up storage space.</p>
                        <button class="install_event_button">Install Now</button>
                    </div>
                    <div class="installmessage_ios">
                        <p> Does not take up storage space. Tap <span> <i class="fa fa-upload" aria-hidden="true"></i> </span> and then "Add to Screen".</p>
                    </div>
                </div>
                <script>
                    var deferredPrompt;
                    var addBtn = document.querySelector(".install_event_button");
                    window.addEventListener("beforeinstallprompt", (e) => {
                        e.preventDefault();
                        deferredPrompt = e;
                    });
                    addBtn.addEventListener("click", (e) => {
                        deferredPrompt.prompt();
                        deferredPrompt.userChoice.then((choiceResult) => {
                            if (choiceResult.outcome === "accepted") {} else {}
                            deferredPrompt = null;
                        });
                    });
                </script> 
            </div>

            <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
            <script>
            $(document).ready(function(){ 
                
                if (window.matchMedia("(display-mode: '.esc_attr($settings['qeapps_pwa_display']).')").matches || localStorage.getItem("easy_pwa_uid")!=null ) {                
                    $(".easy_pwa_cta_banner_section").hide();

                    var navigator_info = window.navigator;
                    var screen_info = window.screen;
                    var uid = navigator_info.mimeTypes.length;
                    uid += navigator_info.userAgent.replace(/\D+/g, "");
                    uid += navigator_info.plugins.length;
                    uid += screen_info.height || "";
                    uid += screen_info.width || "";
                    uid += screen_info.pixelDepth || "";

                    localStorage.setItem("easy_pwa_uid", uid);
                }else{
                    var userAgent = navigator.userAgent;
                    var isMobile = /iPhone|iPad|iPod|Android/i.test(userAgent);
                    if (isMobile==true) {                        
                        var userAgent = navigator.userAgent;
                        if (/android/i.test(userAgent)) {                            
                            $(".easy_pwa_cta_banner_section").show();
                            $(".installmessage_android").show();
                        }
                        if (/iPad|iPhone|iPod/.test(userAgent) && !window.MSStream) {                            
                            $(".easy_pwa_cta_banner_section").show();
                            $(".installmessage_ios").show();
                        }
                    }
                }

                $(".cta_banner_button").click(function(){
                    $(".easy_pwa_cta_banner_section").hide();
                    $(".easy_pwa_cta_banner_popup_section").show(); 
                });
                $(".popup_button_close").click(function(){
                    $(".easy_pwa_cta_banner_section").show();
                    $(".easy_pwa_cta_banner_popup_section").hide(); 
                });
                $(".cta_banner_close").click(function(){
                    $(".easy_pwa_cta_banner_section").hide(); 
                });
            });
            </script>
            ' . PHP_EOL;
  
        $html  .= '<!-- CTA End -->' . PHP_EOL;

        return $html;
    }
}