<?php
if (!defined( 'ABSPATH')) exit;

if( !class_exists('QEApps_manifest') ):
    class QEApps_manifest
    {

        public function qeapps_pwa_url_create( $arg = 'manifest' ) {

            $manifest_filename = qeapps_pwa_get_filename($arg);

            if($arg == "manifest"){
                return site_url().'/'.$manifest_filename;
            }
            
        }

        public function qeapps_pwa_manifest_canonical_style() {

            _e('<link rel="manifest" type="application/json" href="'. parse_url( $this->qeapps_pwa_url_create( 'manifest' ), PHP_URL_PATH ) . '">');
            
            _e('<link rel="canonical" href="'.esc_url(site_url('/')).'"/>');
        }


        public function manifest_to_wp_head() {
            $defaults = qeapps_pwa_get_settings();
            
            add_action( 'wp_head', array( $this, 'qeapps_pwa_manifest_canonical_style' ) );
            
            $head_tags  = '<!-- Manifest added by qeApps - Progressive Web Apps Plugin For WordPress -->' . PHP_EOL;
            $head_tags .= '<meta name="theme-color" content="'.$defaults['qeapps_pwa_theme_color'].'">' . PHP_EOL;
            $head_tags .= '<meta name="description" content="'.$defaults['qeapps_pwa_description'].'">' . PHP_EOL;
            $head_tags .= '<!-- / qeApps.com -->' . PHP_EOL; 
            _e($head_tags);
        }

        
        public function qeapps_pwa_get_settings() {

            $qepwa_install = new QEApps_install();
            $settings = get_option( 'qeapps_pwa_manifest_settings');
            if($settings == ""){
                $qepwa_install->plugin_options_install();
                $settings = get_option( 'qeapps_pwa_manifest_settings');
            }
            return $settings;
        }

        public function qeapps_pwa_get_manifest_file() {
            
            $defaults = qeapps_pwa_get_settings();
            $start_url = $offline_page = esc_url(home_url('/'));

            if( isset($defaults['qeapps_pwa_start_url']) && $defaults['qeapps_pwa_start_url'] > 0 ){
                $start_url = esc_url(get_permalink($defaults['qeapps_pwa_start_url']));
            }
            if( isset($defaults['qeapps_pwa_offline_page']) && $defaults['qeapps_pwa_offline_page'] > 0 ){
                $offline_page = esc_url(get_permalink($defaults['qeapps_pwa_offline_page']));
            }

            $manifest_arr = array(
                'name'  => isset($defaults['qeapps_pwa_name'])?$defaults['qeapps_pwa_name']:get_bloginfo( 'name' ),
                'short_name'  => isset($defaults['qeapps_pwa_short_name'])?$defaults['qeapps_pwa_short_name']:substr( get_bloginfo( 'name' ), 0, 15 ),
                'icons' => 
                array(
                    array( 
                        'src' => isset($defaults['qeapps_pwa_icon'])?$defaults['qeapps_pwa_icon']:esc_url(QEAPPS_APPLICATION_ICON),
                        'sizes' => '192x192',
                        'type' => 'image/png',
                        'purpose' => "any maskable",
                        
                    ),
                    array( 
                        'src' => isset($defaults['qeapps_pwa_splash_icon'])?$defaults['qeapps_pwa_splash_icon']:esc_url(QEAPPS_SPLASH_ICON),
                        'sizes' => '512x512',
                        'type' => 'image/png',
                        
                    ),

                ),                
                'background_color'  => isset($defaults['qeapps_pwa_background_color'])?$defaults['qeapps_pwa_background_color']:'#106d57',
                'background_color'  => isset($defaults['qeapps_pwa_background_color'])?$defaults['qeapps_pwa_background_color']:'#106d57',
                'theme_color'  => isset($defaults['qeapps_pwa_theme_color'])?$defaults['qeapps_pwa_theme_color']:'#15a826',
                'start_url'  => esc_url($start_url),
                'scope'  => esc_url(home_url('/')),
                'orientation'  => isset($defaults['qeapps_pwa_orientation'])?$defaults['qeapps_pwa_orientation']:'portrait',
                'display'  => isset($defaults['qeapps_pwa_display'])?$defaults['qeapps_pwa_display']:'fullscreen',
            );
            if(isset($defaults['qeapps_pwa_description']) && $defaults['qeapps_pwa_description']!=""){
                $manifest_arr['description'] = isset($defaults['qeapps_pwa_description'])?$defaults['qeapps_pwa_description']:'';
            }

            return $manifest_arr;

        }

        public function read_url() {
        
            $url = wp_sanitize_redirect($_SERVER['REQUEST_URI']);
            $parts = explode("/", $url);
            $manifest_filename = qeapps_pwa_get_filename('manifest');
            $service_worker_filename = qeapps_pwa_get_filename('service_worker');
            if( !empty($parts) ){
                if(end($parts) == $manifest_filename){
                    header( 'Content-Type: application/json' );
                    echo wp_json_encode($this->qeapps_pwa_get_manifest_file());
                    exit;
                }
                if(end($parts) == $service_worker_filename){
                    header( 'Content-Type: text/javascript' );
                    _e($this->qeapps_pwa_get_service_worker_settings());
                    exit;
                }
            }
            
        }

        public function qeapps_pwa_add_manifest_to_wp_head() {

            $this->manifest_to_wp_head();
        }


        public function qeapps_pwa_get_service_worker_settings() {
        ob_start();?>
        'use strict';
        const cacheName = '<?php echo esc_attr(parse_url( get_bloginfo( 'url' ), PHP_URL_HOST ) . '-qeappspwa-' . QEAPPS_VERSION); ?>'; 
        const startPage = '<?php echo esc_url( qeapps_pwa_get_start_url() ); ?>';
        const offlinePage = '<?php //echo qeapps_pwa_get_offline_page(); ?>';
        const filesToCache = [];
        const neverCacheUrls = [];
        // Install
        self.addEventListener('install', function(e) {
            console.log('Service worker installation calling!');
        });

        // Activate
        self.addEventListener('activate', function(e) {
            console.log('Service worker activation calling!');
        });

        // Fetch
        self.addEventListener('fetch', function(e) {
            console.log('Service worker fetch calling!');

            // Return if request url protocal isn't http or https
            if ( ! e.request.url.match(/^(http|https):\/\//i) )
                return;

            // Return if request url is from an external domain.
            if ( new URL(e.request.url).origin !== location.origin )
                return;
        });        
        <?php return apply_filters( 'qeapps_pwa_get_service_worker_settings', ob_get_clean() );
        }

    }
endif;