<?php
/*
Plugin Name: Easy Progressive Web App
Description: Convert your WordPress website into a Progressive Web App. 
Version: 1.1
Author: QeApps
*/
if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if( !class_exists('qeApps_pwa') ):

if ( ! defined( 'QEAPPS_VERSION' ) ) {
	define( 'QEAPPS_VERSION'	, '1.1' ); 
}

if ( ! defined( 'QEAPPS_PATH_SRC' ) ) {
	define( 'QEAPPS_PATH_SRC'	, plugin_dir_url( __FILE__ ) ); 
}

if ( ! defined( 'QEAPPS_PLUGIN_FILE' ) ) {
	define( 'QEAPPS_PLUGIN_FILE', __FILE__ ); 
}

if ( ! defined( 'QEAPPS_SPLASH_ICON' ) ) {
	define( 'QEAPPS_SPLASH_ICON', QEAPPS_PATH_SRC . 'images/logo-512x512.png' ); 
}

if ( ! defined( 'QEAPPS_APPLICATION_ICON' ) ) {
	define( 'QEAPPS_APPLICATION_ICON', QEAPPS_PATH_SRC . 'images/logo.png' ); 
}

register_activation_hook( __FILE__, array( 'qeApps_pwa', 'my_plugin_activate' ) );

class qeApps_pwa {

   	public $plugin_directory = "none";
	//plugin class constructor

    public function __construct() {

    	require_once 'inc/QEApps-commonfunction.php';
    	require_once 'inc/QEApps-pwa-install.php';
    	require_once 'inc/QEApps-pwa-manifest.php';
    	require_once 'inc/QEApps-pwa-admin.php';
		
    	// Hook into the admin menu
    	$plugin = plugin_basename(__FILE__);

		 
		add_action ( 'admin_init' , array( $this , 'load_plugin' ) , 1 );
		add_action( 'admin_enqueue_scripts', array( $this,'qeapps_pwa_admin_script') );
		add_action( 'admin_enqueue_scripts', array( $this, 'qeapps_pwa_admin_style' ) );
    	add_action( 'wp_head', array( $this, 'qeapps_pwa_add_manifest_to_wp_head' ),0 );
		add_action( 'wp_footer', array( $this, 'qeapps_pwa_add_manifest_to_wp_footer' ),0 );
    	add_action( 'wp_enqueue_scripts', array( $this, 'qeapps_pwa_service_worker_script' ),999 );
    	add_action( 'admin_menu', array( $this, 'qeapps_pwa_plugin_menu' ) );
    	add_action( 'init', array( $this, 'qeapps_pwa_read_url' ),0 );
		add_action('admin_post_qeappspwa_support', array($this,'qeappspwa_support_process'));
		add_action( 'wp_ajax_nopriv_save_android_count',  array($this,'save_android_count') );
		add_action('wp_ajax_save_android_count', array($this,'save_android_count'));
		
	}

	public static function my_plugin_activate() {
		add_option( 'Activated_Plugin', 'easy-progressive-web-app' );
 
		$response = wp_remote_post( esc_attr('https://qeapps.com/easypwa_installation_data.php') , array(
            'method'      => 'POST',
            'timeout'     => 45,
            'redirection' => 5,
            'httpversion' => '1.0',
            'blocking'    => true,
            'headers'     => array(),
            'body'        => array(
                'store_url' => sanitize_text_field(get_option( 'siteurl' )),
                'store_name' => sanitize_text_field(get_option( 'blogname' )),
                'store_email' => sanitize_text_field(get_option( 'admin_email' )),
				'user_ip' => $_SERVER['REMOTE_ADDR']
            ),
            'cookies'     => array()
            )
        );
         
	}
 
	public function load_plugin() {
		if ( is_admin() && get_option( 'Activated_Plugin' ) == 'easy-progressive-web-app' ) {			 
				delete_option( 'Activated_Plugin' );
				wp_redirect("admin.php?page=easy-progressive-web-app#general-settings");			 
		}
	}
 
	public function save_android_count() {
		$android_option = 0;
		$android_option = get_option('qepwa_android_count', false);
		$android_option = (isset($android_option) && $android_option > 0)? (int)$android_option+1 : 1;
		update_option('qepwa_android_count', $android_option, 'no');
	}

	public function qeapps_pwa_read_url() {
		$manifest = new QEApps_manifest();
		$manifest->read_url();		
	}
	public function qeapps_pwa_admin_script( $hook ) {
		wp_enqueue_media();
		wp_enqueue_script( 'wp-color-picker');
	    wp_enqueue_script( 'qeapps-pwa-js', plugins_url('/js/qeapps_pwa_script.js', __FILE__), array(), '1.0' );
	}

	public function qeapps_pwa_admin_style() {
		wp_enqueue_style( 'wp-color-picker' );
	    wp_enqueue_style( 'qeapps-pwa-css', plugins_url('/css/qeapps_pwa_style.css', __FILE__), false, '1.0.0' );
	    //wp_enqueue_style( 'qeapps-pwa-css' );
	}

	
	public function qeapps_pwa_add_manifest_to_wp_footer() {
		wp_enqueue_style( 'qeapps-pwa-css', plugins_url('/css/qeapps_pwa_front_style.css', __FILE__), false, '1.0.0' );
		_e(qeapps_pwa_cta_banner()); 
	}

	public function qeapps_pwa_add_manifest_to_wp_head() {
		$manifest = new QEApps_manifest();
		$manifest->manifest_to_wp_head(); 
		
		_e(qeapps_pwa_apple_touch_icon()); 
	}

	public function qeapps_pwa_service_worker_script() {

		$service_worker_filename = qeapps_pwa_get_filename('service_worker');

		$defaults = qeapps_pwa_get_settings();

		$qeappsPwaDisableAddToHome = (isset($defaults['qeapps_pwa_disable_add_to_home'])) ? sanitize_text_field($defaults['qeapps_pwa_disable_add_to_home']) : 0;
		$default_addtohomebtn = '
			var deferredPrompt;
			window.addEventListener("beforeinstallprompt", function(e){
				deferredPrompt = e;
				if(deferredPrompt != null || deferredPrompt != undefined){
					if('.$qeappsPwaDisableAddToHome.'==1){
						deferredPrompt.preventDefault();
					}
				}
			})';

	    _e("<script type='text/javascript'>
		if ('serviceWorker' in navigator) {
			window.addEventListener('load', function() {
				navigator.serviceWorker.register('".$service_worker_filename."', { scope: '.' }).then(function(registration) {console.log('Service worker registration successful with scope: ', registration.scope);}, function(err) {console.log('Service worker registration failed: ', err);});
				".$default_addtohomebtn."
			});
		}
		window.addEventListener('appinstalled', (evt) => {
			console.log('Service worker appinstalled calling!');
			const xhttp = new XMLHttpRequest();
			xhttp.open('POST', '".esc_url(admin_url( 'admin-ajax.php' ))."', true);
			xhttp.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');
			xhttp.send('action=save_android_count');
		});	
		</script>");
	}

	public function qeapps_pwa_plugin_menu() {

    	// Add the menu item and page
	    $page_title = 'Easy Progressive Web App';
	    $menu_title = 'Easy PWA';
	    $capability = 'manage_options';
	    $slug = 'easy-progressive-web-app';
	    $callback = array( $this, 'qe_pwa_plugin_dashboard' );
	    $icon = plugins_url('/images/favicon.png', __FILE__);
	    $position = 100;
	    add_menu_page( $page_title, $menu_title, $capability, $slug, $callback, $icon, $position );
	   
	}

	public function qe_pwa_plugin_dashboard() {
		qeapps_dashboard();
	}

	public function qeappspwa_support_process(){

        if (isset($_REQUEST['submit']) && sanitize_text_field($_REQUEST['submit']) == 'Send Message' && isset($_REQUEST['nonce_qeappspwa_support']))
        {

            if (!wp_verify_nonce($_REQUEST['nonce_qeappspwa_support'], 'qeappspwa_support')){
	            wp_die('Invalid nonce..!!');
	            $url = wp_sanitize_redirect(admin_url('admin.php?page=easy-progressive-web-app'));
	            wp_redirect($url);
	            exit;
	        }
	        elseif($_POST['qeappspwa_email'] == ""){
        		update_option('qeappspwa_email_error_message', "Please Enter a valid Email-ID.", 'no');
	            $url = wp_sanitize_redirect(admin_url('admin.php?page=easy-progressive-web-app#pwahelp-settings'));
	            wp_redirect($url);
	            exit;
	        }
	        else{ // SEND MAIL PROCESS START
	        	$ArrData = array(
	        		'email' => sanitize_text_field($_POST['qeappspwa_email']), 
	        		'message'=>sanitize_text_field($_POST['qeappspwa_message']),
	        		'site_url'=>esc_url(site_url()),
	        		'bloginfo'=>get_bloginfo( 'name' ),
	        	);
	        	qeappspwa_send_mail_process($ArrData);
	        }
            
        }

    }
	 
}

new qeApps_pwa();

// end class
endif;
